class DeviceReadings:
    def __init__(self, data):
        self._current_temperature = float(data.CH1currentRoomTemp)
        self._current_target_temperature = float(data.CH1currentSetPoint)
        self._heat_on = data.CH1heatOnOffStatus == "1"
        self._frost_temperature = float(data.frost)

    @property
    def current_temperature(self):
        return self._current_temperature

    @property
    def current_target_temperature(self):
        return self._current_target_temperature

    @property
    def heat_on(self):
        return self._heat_on

    @property
    def frost(self):
        return self.frost




class Device:
    def __init__(self, device_id, name):
        self._id = device_id
        self._name = name

    @property
    def device_id(self):
        return self._id

    @property
    def name(self):
        return self._name

    def __eq__(self, other):
        return self._id == other.device_id and self._name == other.name

    @staticmethod
    def create_from_html(html):
        return Device(
            html.find("input", {"name": "devId"})['value'],
            html.find("a", {"class": "deviceIcon"}).text,
        )



import requests
import json
from types import SimpleNamespace
from bs4 import BeautifulSoup
from cachetools import TTLCache
from salus.device import Device
from salus.device_readings import DeviceReadings

BASE_URL = "https://salus-it500.com/"
URL_LOGIN_API = f"{BASE_URL}public/login.php"
DEVICES_URL = f"{BASE_URL}public/devices.php"
SET_VALUE_URL = f"{BASE_URL}includes/set.php"

LOGIN_PAGE_TEXT = "loginRegister"
INVALID_LOGIN_TEXT = "Invalid login name or password"
INVALID_EMAIL_TEXT = "Please enter a valid email address."


class Api:
    def __init__(self, username, password):
        self._username = username
        self._password = password

        self._session = requests.Session()

        self._cache = TTLCache(maxsize=10, ttl=5 * 60 * 1000)

        self.login()

    def login(self):
        response = self._session.post(URL_LOGIN_API, {
            "IDemail": self._username,
            "password": self._password,
            "login": "Login",
        })

        response_text = response.text

        if response_text.find(INVALID_LOGIN_TEXT) != -1 or response_text.find(INVALID_EMAIL_TEXT) != -1:
            raise Exception("Invalid credentials")

    def get_token_from_api(self):
        self.login()
        devices_list = self._session.get(DEVICES_URL).text
        soup = BeautifulSoup(devices_list, "html.parser")

        token = soup.find("input", {"name": "token"})['value']
        self._cache['token'] = token
        return token

    def get_token(self):
        if self._cache.get("token"):
            return self._cache.get("token")

        return self.get_token_from_api()

    def get_devices(self):
        def request(): return self._session.get(DEVICES_URL).text

        devices_list = self.make_request(request)
        soup = BeautifulSoup(devices_list, "html.parser")

        all_devices_html = soup.select("div.deviceList:has(> a.deviceIcon)")
        return [Device.create_from_html(d) for d in all_devices_html]

    def set_manual_override(self, device_id: str, temperature: float):
        def request(): return self._session.post(
            SET_VALUE_URL,
            {
                "token": self.get_token(),
                "tempUnit": 0,
                "devId": device_id,
                "current_tempZ1_set": 1,
                "current_tempZ1": temperature
            },
        )

        self.make_request(request)

    def get_device_reading(self, device_id):
        token = self.get_token()
        url = self.readings_url(device_id, token)
        readings_data = requests.get(url).text
        response = json.loads(readings_data, object_hook=lambda d: SimpleNamespace(**d))
        return DeviceReadings(response)

    def make_request(self, method):
        response = method()
        if response.find(LOGIN_PAGE_TEXT):
            self.login()
            self._token = self.get_token()
            response = method()

        return response

    @staticmethod
    def readings_url(device_id, token):
        return f"{BASE_URL}/public/ajax_device_values.php?devId={device_id}&token={token}"



from setuptools import setup

setup(
    name='py-salus',
    packages=['salus'],
    version='0.1.2',
    url='https://github.com/cipacda/py-salus',
    description='Python library to integrate with it500 Salus devices',
    long_description='Library to connect to it500 Salus devices.',
    author='cipacda',
    author_email='cipaflorescu@gmail.com',
    license='MIT',
    install_requires=[
        'requests',
        'beautifulsoup4',
        'cachetools',
    ],
    setup_requires=['pytest-runner'],
    tests_require=[
        'pytest==4.4.1',
        'requests_mock',
    ],
    test_suite='tests',
)
